@@ -1,18 +1,15 @@
-/*
+/* 
  * ctcp.h - all the defines for ctcp.c
  *
  */
 
-#define CLIENTINFO \
-        "SED VERSION CLIENTINFO USERINFO ERRMSG FINGER TIME ACTION DCC UTC PING"
+#define CLIENTINFO "SED VERSION CLIENTINFO USERINFO ERRMSG FINGER TIME ACTION DCC UTC PING ECHO  :Use CLIENTINFO <COMMAND> to get more specific information"
 #define CLIENTINFO_SED "SED contains simple_encrypted_data"
 #define CLIENTINFO_VERSION "VERSION shows client type, version and environment"
-#define CLIENTINFO_CLIENTINFO \
-        "CLIENTINFO gives information about available CTCP commands"
+#define CLIENTINFO_CLIENTINFO "CLIENTINFO gives information about available CTCP commands"
 #define CLIENTINFO_USERINFO "USERINFO returns user settable information"
 #define CLIENTINFO_ERRMSG "ERRMSG returns error messages"
-#define CLIENTINFO_FINGER \
-        "FINGER shows real name, login name and idle time of user"
+#define CLIENTINFO_FINGER "FINGER shows real name, login name and idle time of user"
 #define CLIENTINFO_TIME "TIME tells you the time on the user's host"
 #define CLIENTINFO_ACTION "ACTION contains action descriptions for atmosphere"
 #define CLIENTINFO_DCC "DCC requests a direct_client_connection"
